.. nodoctest

Kolakoski Word
==============

.. automodule:: slabbe.kolakoski_word
   :members:
   :undoc-members:
   :show-inheritance:
   
.. automodule:: slabbe.kolakoski_word_pyx
   :members:
   :undoc-members:
   :show-inheritance:
   
